#
# spec file for package sispmctl
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libsispmctl0
Name:           sispmctl
Version:        4.12
Release:        1.2
Summary:        SIS-PM Control for Linux
License:        GPL-2.0-only
URL:            https://sourceforge.net/projects/sispmctl/
Source0:        https://sourceforge.net/projects/sispmctl/files/sispmctl/%{name}-%{version}/%{name}-%{version}.tar.gz
Patch0:         sispmctl-fix-udev-group.patch
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libusb)
BuildRequires:  pkgconfig(udev)

%description
This projects adds support control for the GEMBIRD Silver Shield PM device to linux.

%package -n %{libname}
Summary:        Libraries for sispmctl

%description -n %{libname}
Libraries for the GEMBIRD Silver Shield PM device.

%package devel
Summary:        Development files for sispmctl
Requires:       %{libname} = %{version}

%description devel
Development files for the GEMBIRD Silver Shield PM device.

%prep
%setup -q
%autopatch -p1

%build
%configure \
  --disable-static \
  --enable-webless
%make_build

%install
%make_install
# remove not needed files
rm -r %{buildroot}%{_datadir}/doc/sispmctl/
# Remove static libs
find %{buildroot} -type f -name "*.la" -delete -print

install -Dm 0644 examples/60-sispmctl.rules %{buildroot}%{_udevrulesdir}/60-sispmctl.rules

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%{_mandir}/man1/sispmctl.1%{?ext_man}
%license COPYING
%doc README.md
%{_bindir}/sispmctl
%dir %{_udevrulesdir}
%{_udevrulesdir}/60-sispmctl.rules

%files -n %{libname}
%{_libdir}/libsispmctl.so.*

%files devel
%{_libdir}/libsispmctl.so

%changelog
* Fri Oct 25 2024 Matthias Brugger <mbrugger@suse.com>
- Update to 4.12
  * mention /etc/sispmctl/password in manpage
  * add favicon.ico
  * on USB retry always use the original control data
* Sun Jul  9 2023 Martin Hauke <mardnh@gmx.de>
- Update to 4.11
  * Create /etc/sispmctl/ in passwordsetup.sh
  * Avoid incorrect web output if not in quiet mode
  * Include artwork in distribution file
* Thu Dec 22 2022 Martin Hauke <mardnh@gmx.de>
- Update to 4.10
  * Provide script to create password file
  * Disable ProtectClock in sispmctl.service
  * Minor fixes
* Sat Apr 10 2021 Martin Hauke <mardnh@gmx.de>
- Update to 4.9
  * Correct display of serial number.
  * Fix build error with GCC 4.8.
* Sat Sep 12 2020 Martin Hauke <mardnh@gmx.de>
- Update to 4.8
  * Sleep two seconds upon wrong webserver password.
  * Improve parameter checks.
* Sat Aug 29 2020 Martin Hauke <mardnh@gmx.de>
- Update to 4.7
  * Support scheduling on EG-PMS2
  * Step up security in systemd service definition
- Use sf.net source URL
- Package README.md
* Wed Apr  1 2020 Matthias Brugger <mbrugger@suse.com>
- Update to 4.6
  * Add option to specify powerstrip by USB Bus:Device
  * Improve stability of webserver
* Mon Mar 16 2020 Matthias Brugger <mbrugger@suse.com>
- Update to 4.5
  * add basic authentication for the webserver
  * add bright skin for the webserver
* Mon Mar  9 2020 Matthias Brugger <mbrugger@suse.com>
- Update to 4.4
  * fix man page by adding missing command line option
  * smaller changes to the integrated web server
  * only start example systemd web server service after udev rules are assigned
* Fri Feb 14 2020 Matthias Brugger <mbrugger@suse.com>
- Add patch to change the udev group to dialout
  * add sispmctl-fix-udev-group.patch
* Thu Feb  6 2020 Tomáš Chvátal <tchvatal@suse.com>
- Split devel files to devel subpkg
- Remove unused source file
- Format with spec-cleaner
* Mon Jan 27 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 4.2
- Fix spec file
* Tue Oct  9 2018 Matthias Brugger <mbrugger@suse.com>
- add tool based on
  064850d ("src/sispm_ctl.c: show correct replaced outlet number")
